Object.defineProperty(exports, "__esModule", { value: true });
exports.extractPublicConfig = exports.extractEnvConfig = void 0;
const strip = require("strip-comments");
/**
 * Extract the object part of the string and convert to
 * `
 *  {
 *    NODE_ENV: { required: true },
 *    ENV1: { required: false }, // if `default` exist
 *    ENV2: { devRequired: false }, // if `devDefault` exist
 * }
 * `
 * @param source String
 * @returns
 */
function extractEnvConfig(source) {
    // Extract Object from string
    const cleanVersion = source
        .substring(source.indexOf('/* start */'), source.indexOf('/* end */'))
        .replace('/* start */', '')
        .trim();
    // strip comments, remove spaces and split on new line
    const strippedCleanArray = strip(cleanVersion).replace(/ /g, '').split('\n').filter(Boolean);
    // Counters to check if value of an object key has ended
    let leftBraceCount = 0;
    let rightBraceCount = 0;
    let leftParenthesisCount = 0;
    let rightParenthesisCount = 0;
    // Tracks if value of an object key has devDefault of default
    let hasDefault = false;
    let hasDevDefault = false;
    // Result object
    let finalString = '{';
    // Root object Key
    let key = '';
    // Start from 1 and end 1 before
    // Assuming first and last will be opening and closing paranthesis
    for (let lineIndex = 1; lineIndex < strippedCleanArray.length - 1; lineIndex++) {
        // If starting a new key save the key name
        if (leftBraceCount + rightBraceCount + leftParenthesisCount + rightParenthesisCount === 0) {
            key = strippedCleanArray[lineIndex].substring(0, strippedCleanArray[lineIndex].indexOf(':'));
        }
        // Count paranthesis and braces
        leftBraceCount += strippedCleanArray[lineIndex].split('{').length - 1;
        rightBraceCount += strippedCleanArray[lineIndex].split('}').length - 1;
        leftParenthesisCount += strippedCleanArray[lineIndex].split('(').length - 1;
        rightParenthesisCount += strippedCleanArray[lineIndex].split(')').length - 1;
        if (leftBraceCount !== rightBraceCount || leftParenthesisCount !== rightParenthesisCount) {
            // Check if line has default or devDefault
            if (!hasDefault) {
                hasDefault = strippedCleanArray[lineIndex].includes('default:');
            }
            if (!hasDevDefault) {
                hasDevDefault = strippedCleanArray[lineIndex].includes('devDefault:');
            }
        }
        else {
            // Means a value has ended
            // Reset counters
            leftBraceCount = 0;
            rightBraceCount = 0;
            leftParenthesisCount = 0;
            rightParenthesisCount = 0;
            // Check if line has default or devDefault
            if (!hasDefault) {
                hasDefault = strippedCleanArray[lineIndex].includes('default:');
            }
            if (!hasDevDefault) {
                hasDevDefault = strippedCleanArray[lineIndex].includes('devDefault:');
            }
            let value = '{';
            if (hasDefault) {
                value += 'required:false';
            }
            else {
                value += 'required:true';
            }
            if (hasDevDefault) {
                value += ',devRequired:false}';
            }
            finalString += `${key}:${hasDevDefault ? value : value + '}'},`;
            // Reset default as a value has ended
            hasDefault = false;
            hasDevDefault = false;
        }
    }
    return finalString.substring(0, finalString.length - 1) + '}';
}
exports.extractEnvConfig = extractEnvConfig;
function extractPublicConfig(source) {
    const searchString = 'const publicEnv=[';
    const stripComment = strip(source).replace(/\n/g, ' ').replace(/(?<!\n\s*)[ ]+/g, '').replace('constpublicEnv=[', ' ' + searchString);
    const publicEnvString = stripComment
        .substring(stripComment.indexOf(searchString), stripComment.indexOf(']'))
        .replace(searchString, '')
        .trim();
    return publicEnvString;
}
exports.extractPublicConfig = extractPublicConfig;
//# sourceMappingURL=extract-text.js.map